@@ -18,6 +18,7 @@
  */
 package org.apache.batik.anim.dom;
 
+import java.util.HashMap;
 import java.util.HashSet;
 
 import org.apache.batik.dom.AbstractNode;
@@ -25,7 +26,7 @@ import org.apache.batik.dom.events.AbstractEvent;
 import org.apache.batik.dom.events.EventListenerList;
 import org.apache.batik.dom.events.EventSupport;
 import org.apache.batik.dom.events.NodeEventTarget;
-import org.apache.batik.dom.util.HashTable;
+
 import org.apache.batik.dom.xbl.NodeXBL;
 import org.apache.batik.dom.xbl.ShadowTreeEvent;
 import org.apache.batik.util.XMLConstants;
@@ -42,24 +43,24 @@ import org.w3c.dom.events.MutationEvent;
  * An EventSupport class that handles XBL-specific event processing.
  *
  * @author <a href="mailto:cam%40mcc%2eid%2eau">Cameron McCormack</a>
- * @version $Id: XBLEventSupport.java 1733416 2016-03-03 07:07:13Z gadams $
+ * @version $Id: XBLEventSupport.java 1813521 2017-10-27 12:34:11Z ssteiner $
  */
 public class XBLEventSupport extends EventSupport {
 
     /**
      * The unstoppable capturing listeners table.
      */
-    protected HashTable capturingImplementationListeners;
+    protected HashMap<String, EventListenerList> capturingImplementationListeners;
 
     /**
      * The unstoppable bubbling listeners table.
      */
-    protected HashTable bubblingImplementationListeners;
+    protected HashMap<String, EventListenerList> bubblingImplementationListeners;
 
     /**
      * Map of event types to their aliases.
      */
-    protected static HashTable eventTypeAliases = new HashTable();
+    protected static HashMap<String, String> eventTypeAliases = new HashMap<String, String>();
     static {
         eventTypeAliases.put("SVGLoad",   "load");
         eventTypeAliases.put("SVGUnoad",  "unload");
@@ -124,19 +125,19 @@ public class XBLEventSupport extends EventSupport {
                                                  String type,
                                                  EventListener listener,
                                                  boolean useCapture) {
-        HashTable listeners;
+        HashMap<String, EventListenerList> listeners;
         if (useCapture) {
             if (capturingImplementationListeners == null) {
-                capturingImplementationListeners = new HashTable();
+                capturingImplementationListeners = new HashMap<String, EventListenerList>();
             }
             listeners = capturingImplementationListeners;
         } else {
             if (bubblingImplementationListeners == null) {
-                bubblingImplementationListeners = new HashTable();
+                bubblingImplementationListeners = new HashMap<String, EventListenerList>();
             }
             listeners = bubblingImplementationListeners;
         }
-        EventListenerList list = (EventListenerList) listeners.get(type);
+        EventListenerList list = listeners.get(type);
         if (list == null) {
             list = new EventListenerList();
             listeners.put(type, list);
@@ -151,12 +152,12 @@ public class XBLEventSupport extends EventSupport {
                                                     String type,
                                                     EventListener listener,
                                                     boolean useCapture) {
-        HashTable listeners = useCapture ? capturingImplementationListeners
-                                         : bubblingImplementationListeners;
+        HashMap<String, EventListenerList> listeners = useCapture
+            ? capturingImplementationListeners : bubblingImplementationListeners;
         if (listeners == null) {
             return;
         }
-        EventListenerList list = (EventListenerList) listeners.get(type);
+        EventListenerList list = listeners.get(type);
         if (list == null) {
             return;
         }
@@ -438,12 +439,9 @@ public class XBLEventSupport extends EventSupport {
      */
     public EventListenerList getImplementationEventListeners
             (String type, boolean useCapture) {
-        HashTable listeners = useCapture ? capturingImplementationListeners
-                                         : bubblingImplementationListeners;
-        if (listeners == null) {
-            return null;
-        }
-        return (EventListenerList) listeners.get(type);
+        HashMap<String, EventListenerList> listeners = useCapture
+            ? capturingImplementationListeners : bubblingImplementationListeners;
+        return listeners != null ? listeners.get(type) : null;
     }
 
     /**
