@@ -20,7 +20,6 @@ package org.apache.batik.bridge;
 
 import java.awt.Point;
 import java.awt.event.KeyEvent;
-import java.awt.geom.NoninvertibleTransformException;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
 import java.lang.ref.SoftReference;
@@ -53,7 +52,7 @@ import org.w3c.dom.events.EventTarget;
  * fowarding them to the DOM as regular DOM MouseEvent.
  *
  * @author <a href="mailto:tkormann@ilog.fr">Thierry Kormann</a>
- * @version $Id: BridgeEventSupport.java 1733416 2016-03-03 07:07:13Z gadams $
+ * @version $Id: BridgeEventSupport.java 1805419 2017-08-18 13:04:30Z ssteiner $
  */
 public abstract class BridgeEventSupport implements SVGConstants {
 
@@ -423,7 +422,7 @@ public abstract class BridgeEventSupport implements SVGConstants {
          * event or null if any.
          *
          * @param node the graphics node that received the event
-         * @param coords the mouse coordinates in the GVT tree space
+         * @param pt the mouse coordinates in the GVT tree space
          */
         protected Element getEventTarget(GraphicsNode node, Point2D pt) {
             Element target = context.getElement(node);
@@ -435,21 +434,21 @@ public abstract class BridgeEventSupport implements SVGConstants {
                 if (list != null){
                     float x = (float)pt.getX();
                     float y = (float)pt.getY();
-                    for (int i = 0 ; i < list.size(); i++) {
+                    for (Object aList : list) {
                         StrokingTextPainter.TextRun run =
-                            (StrokingTextPainter.TextRun)list.get(i);
+                                (StrokingTextPainter.TextRun) aList;
                         AttributedCharacterIterator aci = run.getACI();
                         TextSpanLayout layout = run.getLayout();
                         TextHit textHit = layout.hitTestChar(x, y);
                         Rectangle2D bounds = layout.getBounds2D();
                         if ((textHit != null) &&
-                            (bounds != null) && bounds.contains(x, y)) {
+                                (bounds != null) && bounds.contains(x, y)) {
                             SoftReference sr;
-                            sr =(SoftReference)aci.getAttribute
-                                (TEXT_COMPOUND_ID);
+                            sr = (SoftReference) aci.getAttribute
+                                    (TEXT_COMPOUND_ID);
                             Object delimiter = sr.get();
                             if (delimiter instanceof Element) {
-                                return (Element)delimiter;
+                                return (Element) delimiter;
                             }
                         }
                     }
