@@ -42,7 +42,6 @@ import org.apache.batik.dom.AbstractNode;
 import org.apache.batik.dom.events.DOMMouseEvent;
 import org.apache.batik.dom.events.NodeEventTarget;
 import org.apache.batik.dom.svg.LiveAttributeException;
-import org.apache.batik.dom.util.DOMUtilities;
 import org.apache.batik.ext.awt.image.renderable.ClipRable8Bit;
 import org.apache.batik.ext.awt.image.renderable.Filter;
 import org.apache.batik.ext.awt.image.spi.BrokenLinkProvider;
@@ -72,10 +71,10 @@ import org.w3c.dom.svg.SVGImageElement;
 import org.w3c.dom.svg.SVGSVGElement;
 
 /**
- * Bridge class for the &lt;image> element.
+ * Bridge class for the &lt;image&gt; element.
  *
  * @author <a href="mailto:tkormann@apache.org">Thierry Kormann</a>
- * @version $Id: SVGImageElementBridge.java 1733416 2016-03-03 07:07:13Z gadams $
+ * @version $Id: SVGImageElementBridge.java 1805408 2017-08-18 12:21:52Z ssteiner $
  */
 public class SVGImageElementBridge extends AbstractGraphicsNodeBridge {
 
@@ -84,7 +83,7 @@ public class SVGImageElementBridge extends AbstractGraphicsNodeBridge {
     protected BridgeContext subCtx = null;
     protected boolean hitCheckChildren = false;
     /**
-     * Constructs a new bridge for the &lt;image> element.
+     * Constructs a new bridge for the &lt;image&gt; element.
      */
     public SVGImageElementBridge() {}
 
