@@ -53,7 +53,7 @@ import org.apache.batik.util.resources.ResourceManager;
  * The drop down menu component. Supports drop down popup menu and the main
  * button.
  *
- * @version $Id: DropDownComponent.java 1733416 2016-03-03 07:07:13Z gadams $
+ * @version $Id: DropDownComponent.java 1808023 2017-09-11 12:43:22Z ssteiner $
  */
 public class DropDownComponent extends JPanel {
 
@@ -136,7 +136,7 @@ public class DropDownComponent extends JPanel {
                  new PropertyChangeListener() {
                      public void propertyChange(PropertyChangeEvent evt) {
                          setEnabled
-                            (((Boolean) evt.getNewValue()).booleanValue());
+                            ((Boolean) evt.getNewValue());
                      }
                  });
 
@@ -246,7 +246,7 @@ public class DropDownComponent extends JPanel {
     /**
      * The scrollable pop up menu item.
      */
-    public static interface ScrollablePopupMenuItem {
+    public interface ScrollablePopupMenuItem {
 
         /**
          * Selects and deselects the item.
@@ -401,7 +401,7 @@ public class DropDownComponent extends JPanel {
     /**
      * The scrollable popup menu model.
      */
-    public static interface ScrollablePopupMenuModel {
+    public interface ScrollablePopupMenuModel {
 
         /**
          * Gets the footer text for the ScrollablePopupMenu's footer item.
@@ -579,8 +579,8 @@ public class DropDownComponent extends JPanel {
         private int getPreferredWidth() {
             Component[] components = menuPanel.getComponents();
             int maxWidth = 0;
-            for (int i = 0; i < components.length; i++) {
-                int currentWidth = components[i].getPreferredSize().width;
+            for (Component component : components) {
+                int currentWidth = component.getPreferredSize().width;
                 if (maxWidth < currentWidth) {
                     maxWidth = currentWidth;
                 }
@@ -627,8 +627,8 @@ public class DropDownComponent extends JPanel {
                     item.setSelected(wasSelected);
                 }
             } else {
-                for (int i = 0; i < n; i++) {
-                    ScrollablePopupMenuItem item = (ScrollablePopupMenuItem) comps[i];
+                for (Component comp : comps) {
+                    ScrollablePopupMenuItem item = (ScrollablePopupMenuItem) comp;
                     if (item == targetItem) {
                         break;
                     }
@@ -667,8 +667,8 @@ public class DropDownComponent extends JPanel {
         public int getSelectedItemsCount() {
             int selectionCount = 0;
             Component[] components = menuPanel.getComponents();
-            for (int i = 0; i < components.length; i++) {
-                ScrollablePopupMenuItem item = (ScrollablePopupMenuItem) components[i];
+            for (Component component : components) {
+                ScrollablePopupMenuItem item = (ScrollablePopupMenuItem) component;
                 if (item.isSelected()) {
                     selectionCount++;
                 }
@@ -842,7 +842,7 @@ public class DropDownComponent extends JPanel {
      * The ScrollablePopupMenu listener. Handles the events that
      * ScrollablePopupMenu fires
      */
-    public static interface ScrollablePopupMenuListener extends EventListener {
+    public interface ScrollablePopupMenuListener extends EventListener {
 
         /**
          * Handles the 'itemsWereAdded' event.
