@@ -50,7 +50,7 @@ import org.apache.batik.util.HaltingThread;
  * @author <a href="mailto:Thierry.Kormann@sophia.inria.fr">Thierry Kormann</a>
  * @author <a href="mailto:etissandier@ilog.fr">Emmanuel Tissandier</a>
  * @author <a href="mailto:Thomas.DeWeeese@Kodak.com">Thomas DeWeese</a>
- * @version $Id: AbstractGraphicsNode.java 1733416 2016-03-03 07:07:13Z gadams $
+ * @version $Id: AbstractGraphicsNode.java 1808888 2017-09-19 14:22:11Z ssteiner $
  */
 public abstract class AbstractGraphicsNode implements GraphicsNode {
 
@@ -193,7 +193,7 @@ public abstract class AbstractGraphicsNode implements GraphicsNode {
                 inverseTransform = transform.createInverse();
             }catch(NoninvertibleTransformException e){
                 // Should never happen.
-                throw new Error( e.getMessage() );
+                throw new RuntimeException( e.getMessage() );
             }
         } else {
             // The transform is not invertible. Use the same
