@@ -21,7 +21,6 @@ package org.apache.batik.apps.rasterizer;
 import java.awt.Color;
 import java.awt.geom.Rectangle2D;
 import java.io.File;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.StringTokenizer;
 import java.util.List;
@@ -36,14 +35,14 @@ import org.apache.batik.util.ApplicationSecurityEnforcer;
 
 /**
  * Handles command line parameters to configure the <code>SVGConverter</code>
- * and rasterizer images. <br />
+ * and rasterizer images. <br>
  *
  * Each command line option is handled by an <code>OptionHandler</code> which
  * is responsible for converting the option into a configuration of the
  * <code>SVGConverter</code> which is used to perform the conversion.
  *
  * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
- * @version $Id: Main.java 1733416 2016-03-03 07:07:13Z gadams $
+ * @version $Id: Main.java 1808023 2017-09-11 12:43:22Z ssteiner $
  */
 public class Main implements SVGConverterController {
     /**
@@ -55,7 +54,7 @@ public class Main implements SVGConverterController {
     /**
      * Interface for handling one command line option
      */
-    public static interface OptionHandler {
+    public interface OptionHandler {
         /**
          * The <code>OptionHandler</code> should configure the <code>SVGConverter</code>
          * according to the value of the option.
@@ -840,8 +839,8 @@ public class Main implements SVGConverterController {
 
     public Main(String[] args){
         this.args = new ArrayList();
-        for (int i=0; i<args.length; i++){
-            this.args.add(args[i]);
+        for (String arg : args) {
+            this.args.add(arg);
         }
     }
 
@@ -969,14 +968,13 @@ public class Main implements SVGConverterController {
      */
     protected String[] expandSources(List sources){
         List expandedSources = new ArrayList();
-        Iterator iter = sources.iterator();
-        while (iter.hasNext()){
-            String v = (String)iter.next();
+        for (Object source : sources) {
+            String v = (String) source;
             File f = new File(v);
-            if (f.exists() && f.isDirectory()){
+            if (f.exists() && f.isDirectory()) {
                 File[] fl = f.listFiles(new SVGConverter.SVGFileFilter());
-                for (int i=0; i<fl.length; i++){
-                    expandedSources.add(fl[i].getPath());
+                for (File aFl : fl) {
+                    expandedSources.add(aFl.getPath());
                 }
             } else {
                 expandedSources.add(v);
