@@ -43,28 +43,28 @@ import org.apache.batik.util.ParsedURL;
 
 /**
  * This application can be used to convert SVG images to raster images.
- * <br />
+ * <br>
  * Possible result raster image formats are PNG, JPEG, TIFF, and PDF.
  * The Batik Transcoder API is used to execute the conversion. FOP is
- * needed to be able to transcode to the PDF format<br />
+ * needed to be able to transcode to the PDF format<br>
  *
  * The source has to be list of files or URL (set by the <code>setSources</code>
- * method). <br />
+ * method). <br>
  *
- * The destination can be:<br /><ul>
+ * The destination can be:<br><ul>
  * <li><b>unspecified</b>. In that case, only file sources can be converted and
  * a file in the same directory as the source will be created.</li>
  * <li><b>a directory</b>, set by the <code>setDst</code> method. In that case,
  * the output files are created in that destination directory</li>
  * <li><b>a file</b>. In case there is a <i>single
  * source</i>, the destination can be a single named file
- * (set with the <code>setDst</code> method.</li>)<br />
+ * (set with the <code>setDst</code> method.)</li>
  * </ul>
  *
- * <hr />
+ * <hr>
  *
  * There are a number of options which control the way the image is
- * converted to the destination format:<br /><ul>
+ * converted to the destination format:<br><ul>
  * <li>destinationType: controls the type of conversion which should be done.
  *     see the {@link DestinationType} documentation.</li>
  * <li>width/height: they control the desired width and height, in user space,
@@ -92,7 +92,7 @@ import org.apache.batik.util.ParsedURL;
  *     to use when processing the SVG documents.</li>
  * </ul>
  *
- * @version $Id: SVGConverter.java 1733416 2016-03-03 07:07:13Z gadams $
+ * @version $Id: SVGConverter.java 1820736 2018-01-10 11:18:23Z ssteiner $
  * @author <a href="mailto:Henri.Ruini@nokia.com">Henri Ruini</a>
  * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
  */
@@ -470,9 +470,9 @@ public class SVGConverter {
         }
         else{
             this.sources = new ArrayList();
-            for (int i=0; i<sources.length; i++){
-                if (sources[i] != null){
-                    this.sources.add(sources[i]);
+            for (String source : sources) {
+                if (source != null) {
+                    this.sources.add(source);
                 }
             }
 
@@ -736,11 +736,11 @@ public class SVGConverter {
             // exist and we may fail later on in createOutputDir
             //
             int n = sources.size();
-            for(int i=0; i<n; i++){
-                SVGConverterSource src = (SVGConverterSource)sources.get(i);
+            for (Object source : sources) {
+                SVGConverterSource src = (SVGConverterSource) source;
                 // Generate output filename from input filename.
                 File outputName = new File(dst.getPath(),
-                                           getDestinationFile(src.getName()));
+                        getDestinationFile(src.getName()));
                 dstFiles.add(outputName);
 
             }
@@ -751,17 +751,17 @@ public class SVGConverter {
             // sources. This only work if sources are files.
             //
             int n = sources.size();
-            for(int i=0; i<n; i++){
-                SVGConverterSource src = (SVGConverterSource)sources.get(i);
+            for (Object source : sources) {
+                SVGConverterSource src = (SVGConverterSource) source;
                 if (!(src instanceof SVGConverterFileSource)) {
                     throw new SVGConverterException(ERROR_CANNOT_COMPUTE_DESTINATION,
-                                                     new Object[]{src});
+                            new Object[]{src});
                 }
 
                 // Generate output filename from input filename.
-                SVGConverterFileSource fs = (SVGConverterFileSource)src;
+                SVGConverterFileSource fs = (SVGConverterFileSource) src;
                 File outputName = new File(fs.getFile().getParent(),
-                                           getDestinationFile(src.getName()));
+                        getDestinationFile(src.getName()));
                 dstFiles.add(outputName);
             }
 
@@ -784,17 +784,17 @@ public class SVGConverter {
         }
 
         int n = this.sources.size();
-        for (int i=0; i<n; i++){
-            String sourceString = (String)(this.sources.get(i));
+        for (Object source : this.sources) {
+            String sourceString = (String) source;
             File file = new File(sourceString);
             if (file.exists()) {
                 sources.add(new SVGConverterFileSource(file));
             } else {
                 String[] fileNRef = getFileNRef(sourceString);
                 file = new File(fileNRef[0]);
-                if (file.exists()){
+                if (file.exists()) {
                     sources.add(new SVGConverterFileSource(file, fileNRef[1]));
-                } else{
+                } else {
                     sources.add(new SVGConverterURLSource(sourceString));
                 }
             }
@@ -833,12 +833,12 @@ public class SVGConverter {
 
         // Set image quality. ------------------------------------------------
         if (quality > 0) {
-            map.put(JPEGTranscoder.KEY_QUALITY, new Float(this.quality));
+            map.put(JPEGTranscoder.KEY_QUALITY, this.quality);
         }
 
         // Set image indexed. ------------------------------------------------
         if (indexed != -1) {
-            map.put(PNGTranscoder.KEY_INDEXED, new Integer(indexed));
+            map.put(PNGTranscoder.KEY_INDEXED, indexed);
         }
 
         // Set image background color -----------------------------------------
@@ -848,18 +848,18 @@ public class SVGConverter {
 
         // Set image height and width. ----------------------------------------
         if (height > 0) {
-            map.put(ImageTranscoder.KEY_HEIGHT, new Float(this.height));
+            map.put(ImageTranscoder.KEY_HEIGHT, this.height);
         }
         if (width > 0){
-            map.put(ImageTranscoder.KEY_WIDTH, new Float(this.width));
+            map.put(ImageTranscoder.KEY_WIDTH, this.width);
         }
 
         // Set maximum height and width ---------------------------------------
         if (maxHeight > 0) {
-            map.put(ImageTranscoder.KEY_MAX_HEIGHT, new Float(this.maxHeight));
+            map.put(ImageTranscoder.KEY_MAX_HEIGHT, this.maxHeight);
         }
         if (maxWidth > 0){
-            map.put(ImageTranscoder.KEY_MAX_WIDTH, new Float(this.maxWidth));
+            map.put(ImageTranscoder.KEY_MAX_WIDTH, this.maxWidth);
         }
 
         // Set CSS Media
@@ -897,7 +897,7 @@ public class SVGConverter {
         // Sets the millimeters per pixel
         if (pixelUnitToMillimeter > 0){
             map.put(ImageTranscoder.KEY_PIXEL_UNIT_TO_MILLIMETER,
-                    new Float(pixelUnitToMillimeter));
+                    pixelUnitToMillimeter);
         }
 
         // Set validation
@@ -912,7 +912,7 @@ public class SVGConverter {
 
         // Set snapshot time
         if (!Float.isNaN(snapshotTime)) {
-            map.put(ImageTranscoder.KEY_SNAPSHOT_TIME, new Float(snapshotTime));
+            map.put(ImageTranscoder.KEY_SNAPSHOT_TIME, snapshotTime);
         }
 
         // Set allowed scripts
@@ -989,6 +989,7 @@ public class SVGConverter {
             boolean proceed = controller.proceedOnSourceTranscodingFailure
                 (inputFile, outputFile, e.getErrorCode());
             if (proceed){
+                e.printStackTrace();
                 return;
             } else {
                 throw e;
